@@ -204,14 +204,15 @@ def read_mask(mask_path: str) -> sitk.Image:
     return mask
 
 
-def execute(extractor, data, mask, label) -> OrderedDict:
+def execute(extractor, data, mask, label=None) -> OrderedDict:
     feature_data = extractor.execute(data, mask)
-    feature_data[COL_LABEL] = label
+    if label is not None:
+        feature_data[COL_LABEL] = label
     return feature_data
 
 
 def extract_non_ts(data_paths: List[str], mask_paths: List[str],
-                   labels: List[Union[int, float, int]],
+                   labels: List[Union[int, float, int, None]],
                    result_path: str, extractor: RadiomicsFeatureExtractor, lock):
 
     def read_non_ts(data_path, mask_path, label):
@@ -242,7 +243,7 @@ def extract_non_ts(data_paths: List[str], mask_paths: List[str],
             feature_df.to_csv(result_path, index=False, mode="a", header=False)
 
 
-def extract_ts(data_path: str, mask_path: str, label: Union[int, float, int],
+def extract_ts(data_path: str, mask_path: str, label: Union[int, float, int, None],
                result_path: str, extractor: RadiomicsFeatureExtractor):
 
     def read_ts():
